@@ -8,6 +8,10 @@ from t2wml.wikification.wikifier_service import WikifierService
 from t2wml.wikification.wikidata_provider import SparqlProvider, DictionaryProvider, WikidataProvider
 from t2wml.knowledge_graph import KnowledgeGraph, create_output_from_files
 from t2wml.project import Project, ProjectWithSavedState
+from t2wml.input_processing.annotation_parsing import Annotation, AnnotationNodeGenerator, get_Pnode, get_Qnode
+from t2wml.input_processing.annotation_suggesting import block_finder, annotation_suggester
+
+
 
 def add_nodes_from_file(file_path: str):
     warnings.warn("add_nodes_from_file is deprecated, use add_entities_from_file instead", DeprecationWarning)
