@@ -1,7 +1,7 @@
-from t2wml.utils.debug_logging import basic_debug
 import yaml
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.parsing.t2wml_parsing import T2WMLCode
+from t2wml.utils.debug_logging import basic_debug
 
 
 class ForwardSlashEscape(Exception):  # used for a little hack down below
@@ -10,7 +10,6 @@ class ForwardSlashEscape(Exception):  # used for a little hack down below
 
 
 class CodeParser:
-    @basic_debug
     def fix_code_string(self, e_str):
         # we made various compromises between valid code from the get-go and easy for the user code.
         # this function transforms user code into python-acceptable code
@@ -53,7 +52,6 @@ class TemplateParser(CodeParser):
         self.template = template
         self.eval_template = self.create_eval_template(self.template)
 
-    @basic_debug
     def get_code_replacement(self, input_str):
         try:
             if self.is_code_string(input_str):
@@ -88,19 +86,19 @@ class TemplateParser(CodeParser):
 
 
 class Template:
+    @basic_debug
     def __init__(self, dict_template, eval_template):
         self.dict_template = dict_template
         self.eval_template = eval_template
 
     @staticmethod
-    @basic_debug
     def create_from_yaml(yaml_data):
         template = dict(yaml_data)
         template_parser = TemplateParser(template)
         eval_template = template_parser.eval_template
         return Template(template, eval_template)
 
-@basic_debug
+
 def validate_yaml(yaml_file_path):
     with open(yaml_file_path, 'r', encoding="utf-8") as stream:
         try:
@@ -134,7 +132,7 @@ def validate_yaml(yaml_file_path):
                 if isinstance(yaml_region, list):
                     yaml_file_data['statementMapping']['region']=yaml_region[0]
                     yaml_region=yaml_file_data['statementMapping']['region']
-                    #print("Deprecation Warning: region should no longer contain a list")
+                    print("Deprecation Warning: region should no longer contain a list")
                         
                 else:
                     for key in yaml_region.keys():
@@ -166,7 +164,7 @@ def validate_yaml(yaml_file_path):
                 try:
                     #backwards compatibility for versions before 0.0.18
                     subject= yaml_template.pop("item")
-                    #print("DeprecationWarning: using item key instead of subject key")
+                    print("DeprecationWarning: using item key instead of subject key")
                     yaml_template["subject"]=subject
                 except KeyError:
                     pass
@@ -213,4 +211,5 @@ def validate_yaml(yaml_file_path):
 
     if errors:
         raise T2WMLExceptions.ErrorInYAMLFileException(errors)
+
     return yaml_file_data
