@@ -1,5 +1,4 @@
 import os
-from t2wml.utils.debug_logging import t2wml_log
 from pathlib import Path
 import pandas as pd
 from t2wml.spreadsheets.utilities import PandasLoader, load_pickle
@@ -7,7 +6,6 @@ from t2wml.settings import t2wml_settings
 
 class FakeCacher:
     def __init__(self, data_file_path, sheet_name):
-        t2wml_log.debug("using Fake Cacher")
         self.data_file_path = data_file_path
         self.sheet_name = sheet_name
         self.pandas_wrapper = PandasLoader(self.data_file_path)
@@ -26,7 +24,6 @@ def pickle_folder(data_file_path):
 
 class PickleCacher:
     def __init__(self, data_file_path, sheet_name):
-        t2wml_log.debug("using Pickle Cacher")
         self.data_file_path = data_file_path
         self.sheet_name = sheet_name
         self.pandas_wrapper = PandasLoader(self.data_file_path)
