@@ -1,12 +1,13 @@
 from collections import defaultdict
+import json
 import csv
 from pathlib import Path
-from t2wml.utils.debug_logging import basic_debug
 from t2wml.utils.date_utils import VALID_PROPERTY_TYPES
 from SPARQLWrapper.SPARQLExceptions import QueryBadFormed
 from t2wml.utils import t2wml_exceptions as T2WMLExceptions
 from t2wml.wikification.wikidata_provider import DictionaryProvider
 from t2wml.settings import t2wml_settings
+from t2wml.utils.debug_logging import basic_debug
 
 
 def get_default_provider():
@@ -34,7 +35,7 @@ def get_property_type(prop):
         raise T2WMLExceptions.UnsupportedPropertyType(
             "Property not found:" + str(prop))
 
-@basic_debug
+
 def _get_property_type(wikidata_property):
     provider = get_provider()
     property_type = provider.get_property_type(wikidata_property)
@@ -157,6 +158,5 @@ def add_entities_from_file(file_path: str, validate_ids=True):
                 else:
                     return_dict["updated"].append(node_id)
             except Exception as e:
-                #print(e)
                 return_dict["failed"].append((node_id, str(e)))
     return return_dict
\ No newline at end of file
